Module yum — Inmanta 2017.3dev documentation

# Module yum

> - License: Apache 2.0
> - Version: 0.5.0
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/yum.git

## Entities

entity `yum::Repository`

  Parents: `std::Entity`

  A yum repositoy

  attribute string `baseurl`
  attribute bool `enabled`=True
  attribute string `name`
  attribute bool `gpgcheck`=False
  attribute string `gpgkey`=''
  attribute number `metadata_expire`=7200
  relation std::Host `host` [1]

    other end: `std::Host.repos [0:*]`

  The following implementations are defined for this entity:

  > - `yum::redhatRepo`

  The following implements statements select implementations for this entity:

  > - `yum::redhatRepo` constraint `std::familyof(host.os,'redhat')`

## Implementations

implementation `yum::redhatRepo`